package com.bonus.canteen.core.kitchen.mapper;

import java.util.List;
import com.bonus.canteen.core.kitchen.domain.KitchenSampleDishesRecord;

/**
 * 留样机留样清单Mapper接口
 * 
 * @author xsheng
 * @date 2025-06-16
 */
public interface KitchenSampleDishesRecordMapper {
    /**
     * 查询留样机留样清单
     * 
     * @param recordId 留样机留样清单主键
     * @return 留样机留样清单
     */
    public KitchenSampleDishesRecord selectKitchenSampleDishesRecordByRecordId(Long recordId);

    /**
     * 查询留样机留样清单列表
     * 
     * @param kitchenSampleDishesRecord 留样机留样清单
     * @return 留样机留样清单集合
     */
    public List<KitchenSampleDishesRecord> selectKitchenSampleDishesRecordList(KitchenSampleDishesRecord kitchenSampleDishesRecord);

    /**
     * 新增留样机留样清单
     * 
     * @param kitchenSampleDishesRecord 留样机留样清单
     * @return 结果
     */
    public int insertKitchenSampleDishesRecord(KitchenSampleDishesRecord kitchenSampleDishesRecord);

    /**
     * 修改留样机留样清单
     * 
     * @param kitchenSampleDishesRecord 留样机留样清单
     * @return 结果
     */
    public int updateKitchenSampleDishesRecord(KitchenSampleDishesRecord kitchenSampleDishesRecord);

    /**
     * 删除留样机留样清单
     * 
     * @param recordId 留样机留样清单主键
     * @return 结果
     */
    public int deleteKitchenSampleDishesRecordByRecordId(Long recordId);

    /**
     * 批量删除留样机留样清单
     * 
     * @param recordIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKitchenSampleDishesRecordByRecordIds(Long[] recordIds);
}
