package com.bonus.canteen.core.kitchen.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.kitchen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.kitchen.domain.KitchenSampleDishesRecord;
import com.bonus.canteen.core.kitchen.service.IKitchenSampleDishesRecordService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 留样机留样清单Controller
 * 
 * @author xsheng
 * @date 2025-06-16
 */
@Api(tags = "留样机留样清单接口")
@RestController
@RequestMapping("/kitchen_sample_dishes_record")
public class KitchenSampleDishesRecordController extends BaseController {
    @Autowired
    private IKitchenSampleDishesRecordService kitchenSampleDishesRecordService;

    /**
     * 查询留样机留样清单列表
     */
    @ApiOperation(value = "查询留样机留样清单列表")
    //@RequiresPermissions("kitchen:record:list")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody @Valid KitchenSampleDishesRecord kitchenSampleDishesRecord) {
        startPage();
        List<KitchenSampleDishesRecord> list = kitchenSampleDishesRecordService.selectKitchenSampleDishesRecordList(kitchenSampleDishesRecord);
        return getDataTable(list);
    }

    /**
     * 导出留样机留样清单列表
     */
    @ApiOperation(value = "导出留样机留样清单列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:record:export")
    @SysLog(title = "留样机留样清单", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出留样机留样清单")
    @PostMapping("/export")
    public void export(HttpServletResponse response, KitchenSampleDishesRecord kitchenSampleDishesRecord) {
        List<KitchenSampleDishesRecord> list = kitchenSampleDishesRecordService.selectKitchenSampleDishesRecordList(kitchenSampleDishesRecord);
        ExcelUtil<KitchenSampleDishesRecord> util = new ExcelUtil<KitchenSampleDishesRecord>(KitchenSampleDishesRecord.class);
        util.exportExcel(response, list, "留样机留样清单数据");
    }

    /**
     * 获取留样机留样清单详细信息
     */
    @ApiOperation(value = "获取留样机留样清单详细信息")
    //@RequiresPermissions("kitchen:record:query")
    @GetMapping(value = "/{recordId}")
    public AjaxResult getInfo(@PathVariable("recordId") Long recordId) {
        return success(kitchenSampleDishesRecordService.selectKitchenSampleDishesRecordByRecordId(recordId));
    }

    /**
     * 新增留样机留样清单
     */
    @ApiOperation(value = "新增留样机留样清单")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:record:add")
    @SysLog(title = "留样机留样清单", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增留样机留样清单")
    @PostMapping
    public AjaxResult add(@RequestBody KitchenSampleDishesRecord kitchenSampleDishesRecord) {
        try {
            return toAjax(kitchenSampleDishesRecordService.insertKitchenSampleDishesRecord(kitchenSampleDishesRecord));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改留样机留样清单
     */
    @ApiOperation(value = "修改留样机留样清单")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:record:edit")
    @SysLog(title = "留样机留样清单", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改留样机留样清单")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody KitchenSampleDishesRecord kitchenSampleDishesRecord) {
        try {
            return toAjax(kitchenSampleDishesRecordService.updateKitchenSampleDishesRecord(kitchenSampleDishesRecord));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除留样机留样清单
     */
    @ApiOperation(value = "删除留样机留样清单")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:record:remove")
    @SysLog(title = "留样机留样清单", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除留样机留样清单")
	@PostMapping("/del/{recordIds}")
    public AjaxResult remove(@PathVariable Long[] recordIds) {
        return toAjax(kitchenSampleDishesRecordService.deleteKitchenSampleDishesRecordByRecordIds(recordIds));
    }
}
